available_functions = '''

	...try this,

	from vixtor import threeDvector as vix
	print( vix.angbw2line( printing = True ))

>>> Made with LOVE and HARDWORK...

	mod(vector=[2,1,2])

	showline(a=[-1, 0, 2], b=[4, 4, 4], u=10)

	showplane(n=[1, 1, 2])

	line(a=[1, 2, -4], b=[2, 3, 6], 
	two_points=False, sno='', printing=False)
	
	plane(a=[2, 5, -3], n=[-2, -3, 5], p=[5, 3, -3], dis=34,
	nd=False, three_points=False, sno='', printing=False)

	comp_hcf(x=15, y=80)

	angbw2line(a1=[3, 2, -4], b1=[1, 2, 2],
	a2=[5, -2, 0], b2=[3, 2, 6], printing=False)

	distbw2line(a1=[1, 2, -4], b1=[2, 3, 6],
	a2=[3, 3, -5], b2=[2, 3, 6], printing=False)

	coplanof2line(a1=[-3, 1, 5], b1=[-3, 1, 5],
	a2=[-1, 2, 5], b2=[-1, 2, 5], printing=False)

	angbw2plane(n1=[3, -6, 2], d1=7,
	n2=[2, 1, -2], d2=5, printing=False)

	distbwpointandplane(a=[2, 5, -3],
	n=[6, -3, 2], d=4, printing=False)

	angbwlineandplane(a=[2, 5, -3], b=[3, 5, 1],
	n=[6, -3, 2], d=4, printing=False)

....The moving power of mathematical invention is not 
reasoning but imagination. – A.DEMORGAN
'''

print('\n>>> Available functions in vixtor Package are...\n', available_functions)
